@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.GIT, Copyright by Tobi Oetiker
+ * RRDtool 1.7.2 Copyright by Tobi Oetiker
  *****************************************************************************
  * rrd_open.c  Open an RRD File
  *****************************************************************************
@@ -35,18 +35,23 @@
 #define MEMBLK 8192
 
 #ifdef _WIN32
-#define	_LK_UNLCK	0   /* Unlock */
-#define	_LK_LOCK	1   /* Lock */
-#define	_LK_NBLCK	2   /* Non-blocking lock */
-#define	_LK_RLCK	3   /* "Same as _LK_NBLCK" */
-#define	_LK_NBRLCK	4   /* "Same as _LK_LOCK" */
+#define    _LK_UNLCK    0   /* Unlock */
+#define    _LK_LOCK     1   /* Lock */
+#define    _LK_NBLCK    2   /* Non-blocking lock */
+#define    _LK_RLCK     3   /* "Same as _LK_NBLCK" */
+#define    _LK_NBRLCK   4   /* "Same as _LK_LOCK" */
 
 
-#define	LK_UNLCK	_LK_UNLCK
-#define	LK_LOCK		_LK_LOCK
-#define	LK_NBLCK	_LK_NBLCK
-#define	LK_RLCK		_LK_RLCK
-#define	LK_NBRLCK	_LK_NBRLCK
+#define    LK_UNLCK    _LK_UNLCK
+#define    LK_LOCK     _LK_LOCK
+#define    LK_NBLCK    _LK_NBLCK
+#define    LK_RLCK     _LK_RLCK
+#define    LK_NBRLCK   _LK_NBRLCK
+
+/* Variables for CreateFileA(). Names of variables are according to
+ * https://docs.microsoft.com/en-us/windows/desktop/api/fileapi/nf-fileapi-createfilea */
+DWORD     dwDesiredAccess = 0;
+DWORD     dwCreationDisposition = 0;
 #endif
 
 /* DEBUG 2 prints information obtained via mincore(2) */
@@ -61,60 +66,61 @@
    versions of gcc: 'cast increases required alignment of target type'
 */
 #define __rrd_read_mmap(dst, dst_t, cnt) { \
-	size_t wanted = sizeof(dst_t)*(cnt); \
-	if (offset + wanted > rrd_file->file_len) { \
-		rrd_set_error("reached EOF while loading header " #dst); \
-		goto out_close; \
-	} \
-	(dst) = (dst_t*)(void*) (data + offset); \
-	offset += wanted; \
+    size_t wanted = sizeof(dst_t)*(cnt); \
+    if (offset + wanted > rrd_file->file_len) { \
+        rrd_set_error("reached EOF while loading header " #dst); \
+        goto out_close; \
+    } \
+    (dst) = (dst_t*)(void*) (data + offset); \
+    offset += wanted; \
     }
 #else
 #define __rrd_read_seq(dst, dst_t, cnt) { \
-	size_t wanted = sizeof(dst_t)*(cnt); \
+    size_t wanted = sizeof(dst_t)*(cnt); \
         size_t got; \
-	if ((dst = (dst_t*)malloc(wanted)) == NULL) { \
-		rrd_set_error(#dst " malloc"); \
-		goto out_close; \
-	} \
+    if ((dst = (dst_t*)malloc(wanted)) == NULL) { \
+        rrd_set_error(#dst " malloc"); \
+        goto out_close; \
+    } \
         got = read (rrd_simple_file->fd, dst, wanted); \
-	if (got != wanted) { \
-		rrd_set_error("short read while reading header " #dst); \
-                goto out_close; \
-	} \
-	offset += got; \
+    if (got != wanted) { \
+        rrd_set_error("short read while reading header " #dst); \
+        goto out_close; \
+    } \
+    offset += got; \
     }
 #endif
 
 #ifdef HAVE_LIBRADOS
 #define __rrd_read_rados(dst, dst_t, cnt) { \
-	size_t wanted = sizeof(dst_t)*(cnt); \
+    size_t wanted = sizeof(dst_t)*(cnt); \
         size_t got; \
-	if ((dst = (dst_t*)malloc(wanted)) == NULL) { \
-		rrd_set_error(#dst " malloc"); \
-		goto out_close; \
-	} \
+    if ((dst = (dst_t*)malloc(wanted)) == NULL) { \
+        rrd_set_error(#dst " malloc"); \
+        goto out_close; \
+    } \
         got = rrd_rados_read(rrd_file->rados, dst, wanted, offset); \
-	if (got != wanted) { \
-		rrd_set_error("short read while reading header " #dst); \
-                goto out_close; \
-	} \
-	offset += got; \
+    if (got != wanted) { \
+        rrd_set_error("short read while reading header " #dst); \
+        goto out_close; \
+    } \
+    offset += got; \
     }
 #endif
 
 #if defined(HAVE_LIBRADOS) && defined(HAVE_MMAP)
 #define __rrd_read(dst, dst_t, cnt) { \
     if (rrd_file->rados) \
-      __rrd_read_rados(dst, dst_t, cnt) \
+        __rrd_read_rados(dst, dst_t, cnt) \
     else \
-      __rrd_read_mmap(dst, dst_t, cnt) \
+        __rrd_read_mmap(dst, dst_t, cnt) \
     }
 #elif defined(HAVE_LIBRADOS) && !defined(HAVE_MMAP)
-if (rrd_file->rados)
-    __rrd_read_rados(dst, dst_t, cnt)
-        else
-    __rrd_read_seq(dst, dst_t, cnt)
+#define __rrd_read(dst, dst_t, cnt) { \
+    if (rrd_file->rados) \
+        __rrd_read_rados(dst, dst_t, cnt) \
+    else \
+        __rrd_read_seq(dst, dst_t, cnt) \
     }
 #elif defined(HAVE_MMAP)
 #define __rrd_read(dst, dst_t, cnt) \
@@ -236,6 +242,10 @@ rrd_file_t *rrd_open(
 
     if (rdwr & RRD_READONLY) {
         flags |= O_RDONLY;
+#ifdef _WIN32
+        dwDesiredAccess = GENERIC_READ;
+        dwCreationDisposition = OPEN_EXISTING;
+#endif
 #ifdef HAVE_MMAP
 # if !defined(AIX)
         rrd_simple_file->mm_flags = MAP_PRIVATE;
@@ -247,6 +257,10 @@ rrd_file_t *rrd_open(
     } else {
         if (rdwr & RRD_READWRITE) {
             flags |= O_RDWR;
+#ifdef _WIN32
+            dwDesiredAccess = GENERIC_READ | GENERIC_WRITE;
+            dwCreationDisposition = OPEN_EXISTING;
+#endif
 #ifdef HAVE_MMAP
             rrd_simple_file->mm_flags = MAP_SHARED;
             rrd_simple_file->mm_prot |= PROT_WRITE;
@@ -254,9 +268,17 @@ rrd_file_t *rrd_open(
         }
         if (rdwr & RRD_CREAT) {
             flags |= (O_CREAT | O_TRUNC);
+#ifdef _WIN32
+            dwDesiredAccess = GENERIC_READ | GENERIC_WRITE;
+            dwCreationDisposition = CREATE_ALWAYS;
+#endif
         }
         if (rdwr & RRD_EXCL) {
             flags |= O_EXCL;
+#ifdef _WIN32
+            dwDesiredAccess = GENERIC_READ | GENERIC_WRITE;
+            dwCreationDisposition = CREATE_NEW;
+#endif
         }
     }
     if (rdwr & RRD_READAHEAD) {
@@ -278,9 +300,20 @@ rrd_file_t *rrd_open(
     HANDLE    handle;
 
     handle =
-        CreateFileA(file_name, GENERIC_READ | GENERIC_WRITE,
+        CreateFileA(file_name, dwDesiredAccess,
                     FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
-                    NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, NULL);
+                    NULL, dwCreationDisposition, FILE_ATTRIBUTE_NORMAL, NULL);
+    if (handle == INVALID_HANDLE_VALUE) {
+        LPVOID    lpMsgBuf = NULL;
+
+        FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER |
+                      FORMAT_MESSAGE_FROM_SYSTEM |
+                      FORMAT_MESSAGE_IGNORE_INSERTS, NULL, GetLastError(), 0,
+                      (LPTSTR) & lpMsgBuf, 0, NULL);
+        rrd_set_error("opening '%s': %s", file_name, (LPTSTR) lpMsgBuf);
+        LocalFree(lpMsgBuf);
+        goto out_free;
+    }
     if ((rrd_simple_file->fd = _open_osfhandle((intptr_t) handle, flags)) < 0) {
         rrd_set_error("opening '%s': %s", file_name, rrd_strerror(errno));
         goto out_free;
@@ -351,7 +384,9 @@ rrd_file_t *rrd_open(
             goto out_close;
         }
     }
+#ifdef HAVE_POSIX_FALLOCATE
   no_lseek_necessary:
+#endif
 
 #ifdef HAVE_MMAP
 #ifndef HAVE_POSIX_FALLOCATE
@@ -748,6 +783,8 @@ int rrd_rwlock(
 #ifdef USE_WINDOWS_LOCK
     /* _locking() does not support read locks; we always take a write lock */
     rcstat = rrd_windows_lock(rrd_simple_file->fd);
+    /* Silence unused parameter compiler warning */
+    (void) writelock;
 #else
     {
         struct flock lock;
@@ -843,6 +880,11 @@ void rrd_dontneed(
 #if defined DEBUG && DEBUG > 1
     mincore_print(rrd_file, "after");
 #endif
+#else                           /* #if defined USE_MADVISE || defined HAVE_POSIX_FADVISE */
+    /* Silence compiler warnings about unused variables and parameters */
+    (void) rrd_simple_file;
+    (void) rrd_file;
+    (void) rrd;
 #endif                          /* without madvise and posix_fadvise it does not make much sense todo anything */
 }
 
